package org.ow2.bonita.example.carpool.hook;

import java.util.logging.Level;
import java.util.logging.Logger;

import org.ow2.bonita.definition.TxHook;
import org.ow2.bonita.facade.APIAccessor;
import org.ow2.bonita.facade.RuntimeAPI;
import org.ow2.bonita.facade.runtime.ActivityBody;
import org.ow2.bonita.facade.runtime.ActivityInstance;
import org.ow2.bonita.facade.runtime.ActivityState;
import org.ow2.bonita.facade.runtime.TaskInstance;
import org.ow2.bonita.facade.uuid.TaskUUID;
import org.ow2.bonita.util.BonitaRuntimeException;

public class WaitAnswerDL implements TxHook {

  private static final Logger LOG = Logger.getLogger(WaitAnswerDL.class.getName());

  public void execute(final APIAccessor apiAccessor, final ActivityInstance<ActivityBody> activity) throws Exception {
    if (LOG.isLoggable(Level.INFO)) {
      LOG.info("\n***** Executing Hook: " + this.getClass().getName() + " *****\n");
    }

    final String activityId = activity.getActivityId();
    TaskInstance t = (TaskInstance)activity.getBody();
    final TaskUUID taskUUID = t.getUUID();
    final RuntimeAPI runtimeAPI = apiAccessor.getRuntimeAPI();

    if (LOG.isLoggable(Level.INFO)) {
      LOG.info("\n***** Starting task associated to activity: " + activityId + " *****\n");
    }
    runtimeAPI.startTask(taskUUID, true);

    final ActivityInstance<TaskInstance> activity2 = apiAccessor.getQueryRuntimeAPI().getTask(taskUUID);
    if (activity2 == null) {
      throw new BonitaRuntimeException("Activity2 is null!");
    }
    t = activity2.getBody();
    if (!ActivityState.EXECUTING.equals(t.getState())) {
      throw new BonitaRuntimeException("Task is in a wrong state! Expected: " 
          + ActivityState.EXECUTING + ", found is: " + t.getState());
    }

    if (LOG.isLoggable(Level.INFO)) {
      LOG.info("\n***** Finishing task associated to activity: " + activityId + " *****\n");
    }
    runtimeAPI.finishTask(taskUUID, true);
  }

}
